@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 12940 2021-06-03 15:19:56Z Lavender $
+# $Id: __init__.py 13083 2021-07-20 09:04:36Z Mint $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,9 +11,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: Lavender $ (last)
-# $Date: 2021-06-03 23:19:56 +0800 (Thu, 03 Jun 2021) $
-# $Revision: 12940 $
+# $Author: Mint $ (last)
+# $Date: 2021-07-20 17:04:36 +0800 (Tue, 20 Jul 2021) $
+# $Revision: 13083 $
 
 import os
 import sys
@@ -229,7 +229,7 @@ def attachSettings(settingsDict, enableFacebook=False, enableGoogle=False,
             settingsDict['DEFAULT_HTTP_PROTOCOL'] = 'https'
             
     #=========================================================================
-    if getattr(settingsDict, "IUNO_MEMBER_TRAC_ENABLE", True):
+    if getattr(settingsDict, "IUNO_MEMBER_TRAC_ENABLE", False):
         # trac login
         tracDefaults = {
             'DEFAULT_TRAC_AUTH_URL': 'https://code.nuwainfo.com/aec359bc3cfadb7504f26461a4c06625',
