@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: forms.py 12301 2020-06-03 06:08:57Z Lavender $
+# $Id: forms.py 13327 2021-09-13 07:00:54Z Becca $
 #
 # Copyright (c) 2018 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,9 +11,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: Lavender $ (last)
-# $Date: 2020-06-03 14:08:57 +0800 (Wed, 03 Jun 2020) $
-# $Revision: 12301 $
+# $Author: Becca $ (last)
+# $Date: 2021-09-13 15:00:54 +0800 (Mon, 13 Sep 2021) $
+# $Revision: 13327 $
 
 import os
 import re
@@ -335,7 +335,9 @@ class ShippingAddressForm2(ShippingAddressForm1):
     )
     ordererPostcode = forms.CharField(
         label=_('Orderer postcode'), required=True)
-    
+    ordererPhone = forms.CharField(
+      label=_('Orderer phone'), required=True)
+
     class Meta(ShippingAddressForm1.Meta):
         
         fields = [
